@@ -2,7 +2,7 @@
 #
 # Script to install Shoreline Firewall Lite
 #
-#     This program is under GPL [http://www.gnu.org/copyleft/gpl.htm]
+#     This program is under GPL [http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt]
 #
 #     (c) 2000,2001,2002,2003,2004,2005,2006,2007 - Tom Eastep (teastep@shorewall.net)
 #
@@ -19,10 +19,10 @@
 #
 #       You should have received a copy of the GNU General Public License
 #       along with this program; if not, write to the Free Software
-#       Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
+#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-VERSION=3.4.4
+VERSION=4.0.6
 
 usage() # $1 = exit status
 {
@@ -308,7 +308,7 @@ echo "Common functions linked through ${PREFIX}/usr/share/shorewall-lite/functio
 # Install Shorecap
 #
 
-install_file shorecap ${PREFIX}/usr/share/shorewall-lite/shorecap 0555
+install_file shorecap ${PREFIX}/usr/share/shorewall-lite/shorecap 0755
 
 echo
 echo "Capability file builder installed in ${PREFIX}/usr/share/shorewall-lite/shorecap"
@@ -317,7 +317,7 @@ echo "Capability file builder installed in ${PREFIX}/usr/share/shorewall-lite/sh
 # Install wait4ifup
 #
 
-install_file wait4ifup ${PREFIX}/usr/share/shorewall-lite/wait4ifup 0555
+install_file wait4ifup ${PREFIX}/usr/share/shorewall-lite/wait4ifup 0755
 
 echo
 echo "wait4ifup installed in ${PREFIX}/usr/share/shorewall-lite/wait4ifup"
@@ -334,17 +334,15 @@ echo "Modules file installed as ${PREFIX}/usr/share/shorewall-lite/modules"
 
 cd manpages
 
-rm -f *.gz
-
 for f in *.5; do
-    gzip $f
-    run_install -D -m 444 $f.gz ${PREFIX}/usr/share/man/man5/$f.gz
+    gzip -c $f > $f.gz
+    run_install -D -m 644 $f.gz ${PREFIX}/usr/share/man/man5/$f.gz
     echo "Man page $f.gz installed to /usr/share/man/man5/$f.gz"
 done
 
 for f in *.8; do
-    gzip $f
-    run_install -D -m 444 $f.gz ${PREFIX}/usr/share/man/man8/$f.gz
+    gzip -c $f > $f.gz
+    run_install -D -m 644 $f.gz ${PREFIX}/usr/share/man/man8/$f.gz
     echo "Man page $f.gz installed to /usr/share/man/man8/$f.gz"
 done
 
